// src/lib/server/mqtt-devices.js
// This module provides access to MQTT device data for other parts of the application

// We'll import the maps directly from the MQTT server module

let connectedDevices = new Map();
let deviceSensorData = new Map();

// Export the maps so the MQTT server can set them
export { connectedDevices, deviceSensorData };

// Clean up offline devices (not seen in last 5 minutes)
function cleanupDevices() {
  const fiveMinutesAgo = new Date(Date.now() - 5 * 60 * 1000);
  let updated = false;

  for (const [deviceId, device] of connectedDevices.entries()) {
    if (device.lastSeen < fiveMinutesAgo && device.status === "online") {
      connectedDevices.set(deviceId, { ...device, status: "offline" });
      updated = true;
    }
  }

  return updated;
}

// Export function to get current devices
export function getCurrentDevices() {
  cleanupDevices();
  return Array.from(connectedDevices.values()).map((device) => {
    const sensorData = deviceSensorData.get(device.id);
    return {
      ...device,
      sensorData: sensorData || null,
    };
  });
}

// Export function to get sensor data for a specific device
export function getDeviceSensorData(deviceId) {
  return deviceSensorData.get(deviceId) || null;
}
